source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")
source("modules/Indices/Indices.R")
source("modules/Downscaling/Downscaling.R")
source("SUNSET_PROV/R/SunsetProv.Command.R")

library(igraph)

# Read recipe
recipe_file <- "tests_provenance/recipes/recipe_test_provenance2.yml"
recipe <- prepare_outputs(recipe_file)

#Load datasets
data <- Loading(recipe)

#Compute anomalies
data <- Anomalies(recipe, data)

#Compute El Nino indices
nino_data <- Indices(recipe, data)

#Compute skill metrics
graph.prov <- nino_data$graph.prov
nino_data$graph.prov <- NULL

for (index in nino_data) {
  index$graph.prov <- graph.prov
  nino_skill_metrics <- Skill(recipe = recipe, data = index, agg = "region")
  graph.prov <- nino_skill_metrics$graph.prov
  nino_skill_metrics$graph.prov <- NULL
}

#Generate JSON file
graph2json(graph.prov$graph,
           "/esarchive/scratch/apuiggro/sunset/tests_provenance/out-logs/json_test2.json")

rm(list = ls())

print("Test 2 succesfull")