source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")
source("SUNSET_PROV/R/SunsetProv.Command.R")

library(igraph)

#SUNSET loading module execution
recipe_file <- "tests_provenance/recipes/recipe_test_provenance4.yml"

#Loading MODULE
recipe <- prepare_outputs(recipe_file)
data <- Loading(recipe)

#Calibration MODULE
data_cal <- Calibration(recipe, data)

#Anomalies MODULE
data_ano <- Anomalies(recipe, data_cal)

#Compute skill metrics
skill_metrics <- Skill(recipe, data_ano)

#Compute percentiles and probability bins
probabilities <- Probabilities(recipe, data)

#Define provenance graph for Visualization
graph.prov <- skill_metrics$graph.prov

#Visualization
Visualization(recipe, data, graph.prov,
              skill_metrics = skill_metrics,
              probabilities = probabilities,
              significance = TRUE)

#Generate JSON file
graph2json(graph.prov$graph,
           "/esarchive/scratch/apuiggro/sunset/tests_provenance/out-logs/json_test4.json")

rm(list = ls())

print("Test 4 successfull")