###########################################

source("modules/Loading/Loading.R")
source("modules/Calibration/Calibration.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")
source("SUNSET_PROV/R/SunsetProv.Command.R")

library(igraph)

recipe_file <- "tests_provenance/recipes/recipe_test_provenance5.yml"
recipe <- prepare_outputs(recipe_file)
archive <- read_yaml("conf/archive_decadal.yml")

# Load datasets
data <- Loading(recipe)

# Calibrate datasets
calibrated_data <- Calibration(recipe, data)

# Compute skill metrics
skill_metrics <- Skill(recipe, calibrated_data)

probs <- Probabilities(recipe, calibrated_data)

graph.prov <- skill_metrics$graph.prov

# Plotting
Visualization(recipe = recipe, data = calibrated_data, graph.prov,
              skill_metrics = skill_metrics, probabilities = probs,
              significance = T )

#Generate JSON file
graph2json(graph.prov$graph,
           "/esarchive/scratch/apuiggro/sunset/tests_provenance/out-logs/json_test5.json")

rm(list = ls())

print("Test 5 successfull")